@@ -4,8 +4,7 @@ mod interactive_print;
 mod json_print;
 
 use crate::lang::SgLang;
-use ast_grep_config::RuleConfig;
-use ast_grep_core::replacer::TemplateFix;
+use ast_grep_config::{Fixer, RuleConfig};
 use ast_grep_core::{Matcher, NodeMatch as SgNodeMatch, StrDoc};
 
 use anyhow::Result;
@@ -63,13 +62,14 @@ pub struct Diff<'n> {
   pub node_match: NodeMatch<'n, SgLang>,
   /// string content for the replacement
   pub replacement: Cow<'n, str>,
+  pub range: std::ops::Range<usize>,
 }
 
 impl<'n> Diff<'n> {
   pub fn generate(
     node_match: NodeMatch<'n, SgLang>,
     matcher: &impl Matcher<SgLang>,
-    rewrite: &TemplateFix<String>,
+    rewrite: &Fixer<String, SgLang>,
   ) -> Self {
     let edit = node_match.make_edit(matcher, rewrite);
     let replacement = String::from_utf8(edit.inserted_text).unwrap();
@@ -77,8 +77,16 @@ impl<'n> Diff<'n> {
     Self {
       node_match,
       replacement,
+      range: edit.position..edit.position + edit.deleted_length,
     }
   }
+
+  /// Returns the root doc source code
+  /// N.B. this can be different from node.text() because
+  /// tree-sitter's root Node may not start at the begining
+  pub fn get_root_text(&self) -> &'n str {
+    self.node_match.root().get_text()
+  }
 }
 
 #[derive(ValueEnum, Clone, Copy)]
