@@ -1,7 +1,7 @@
 use std::path::{Path, PathBuf};
 
 use anyhow::{Context, Result};
-use ast_grep_core::replacer::TemplateFix;
+use ast_grep_config::Fixer;
 use ast_grep_core::{Matcher, Pattern};
 use ast_grep_language::Language;
 use clap::Parser;
@@ -154,7 +154,7 @@ impl<P: Printer + Sync> Worker for RunWithInferredLang<P> {
     for (match_unit, lang) in items {
       let rewrite = rewrite
         .as_ref()
-        .map(|s| TemplateFix::try_new(s, &lang))
+        .map(|s| Fixer::from_str(s, &lang))
         .transpose();
       match rewrite {
         Ok(r) => match_one_file(printer, &match_unit, &r)?,
@@ -214,7 +214,7 @@ impl<P: Printer + Sync> Worker for RunWithSpecificLang<P> {
       println!("Pattern TreeSitter {:?}", self.pattern);
     }
     let rewrite = if let Some(s) = &arg.rewrite {
-      Some(TemplateFix::try_new(s, &lang).context(EC::ParsePattern)?)
+      Some(Fixer::from_str(s, &lang).context(EC::ParsePattern)?)
     } else {
       None
     };
@@ -261,7 +261,7 @@ impl<P: Printer + Sync> StdInWorker for RunWithSpecificLang<P> {
 fn match_one_file(
   printer: &impl Printer,
   match_unit: &MatchUnit<impl Matcher<SgLang>>,
-  rewrite: &Option<TemplateFix<String>>,
+  rewrite: &Option<Fixer<String, SgLang>>,
 ) -> Result<()> {
   let MatchUnit {
     path,
