@@ -1,4 +1,4 @@
-use crate::fixer::Fixer;
+use crate::fixer::{Fixer, FixerError, SerializableFixer};
 use crate::rule::{RuleSerializeError, SerializableRule};
 use crate::transform::Transformation;
 use crate::DeserializeEnv;
@@ -11,7 +11,6 @@ pub use crate::constraints::{
 use ast_grep_core::language::Language;
 use ast_grep_core::meta_var::MetaVarMatchers;
 use ast_grep_core::replacer::{IndentSensitive, Replacer};
-use ast_grep_core::replacer::{TemplateFix, TemplateFixError};
 use ast_grep_core::{NodeMatch, StrDoc};
 use schemars::JsonSchema;
 use serde::{Deserialize, Serialize};
@@ -115,7 +114,7 @@ pub struct SerializableRuleConfig<L: Language> {
   #[serde(default)]
   pub severity: Severity,
   /// A pattern to auto fix the issue. It can reference metavariables appeared in rule.
-  pub fix: Option<Fixer>,
+  pub fix: Option<SerializableFixer>,
   /// Glob patterns to specify that the rule only applies to matching files
   pub files: Option<Vec<String>>,
   /// Glob patterns that exclude rules from applying to files
@@ -129,18 +128,12 @@ pub struct SerializableRuleConfig<L: Language> {
 type RResult<T> = std::result::Result<T, RuleConfigError>;
 
 impl<L: Language> SerializableRuleConfig<L> {
-  pub fn get_fixer<C: IndentSensitive>(&self) -> RResult<Option<TemplateFix<C>>> {
-    if let Some(Fixer::Str(fix)) = &self.fix {
-      if let Some(trans) = &self.transform {
-        let keys: Vec<_> = trans.keys().cloned().collect();
-        Ok(Some(TemplateFix::with_transform(
-          fix,
-          &self.language,
-          &keys,
-        )))
-      } else {
-        Ok(Some(TemplateFix::try_new(fix, &self.language)?))
-      }
+  pub fn get_fixer<C: IndentSensitive>(&self) -> RResult<Option<Fixer<C, L>>> {
+    let transform = &self.transform;
+    if let Some(fixer) = &self.fix {
+      let env = self.get_deserialize_env(&Default::default())?;
+      let parsed = Fixer::parse(fixer, &env, transform)?;
+      Ok(Some(parsed))
     } else {
       Ok(None)
     }
@@ -172,7 +165,7 @@ pub enum RuleConfigError {
   #[error("Rule is not configured correctly.")]
   Rule(#[from] RuleSerializeError),
   #[error("fix pattern is invalid.")]
-  Fixer(#[from] TemplateFixError),
+  Fixer(#[from] FixerError),
   #[error("constraints is not configured correctly.")]
   Constraints(#[from] SerializeConstraintsError),
 }
@@ -180,7 +173,7 @@ pub enum RuleConfigError {
 pub struct RuleConfig<L: Language> {
   inner: SerializableRuleConfig<L>,
   pub matcher: RuleWithConstraint<L>,
-  pub fixer: Option<TemplateFix<String>>,
+  pub fixer: Option<Fixer<String, L>>,
 }
 
 impl<L: Language> RuleConfig<L> {
